@@ -2,7 +2,7 @@ import requests
 import os
 from digitalguide.WhatsAppUpdate import WhatsAppUpdate
 from digitalguide.send_utils import send_interactive_list, send_sticker, send_typing_indicator
-
+from digitalguide.db_objects import WhatsAppInteraction, WhatsAppUser
 import redis
 from time import sleep
 
@@ -22,37 +22,35 @@ class Action():
         self.action_functions = action_functions
         
     def __call__(self, client, update: WhatsAppUpdate, context):
-        send_typing_indicator(client, update.get_message_id())
-        if not ("user_id" in context.keys()):
-            from digitalguide.db_objects import WhatsAppUser
-            db_user = WhatsAppUser(ProfileName=update.entry[0].changes[0].value.contacts[0].profile_name,
-                                   WaId=update.get_from())
-            db_user.save()
-            context["user_id"] = db_user
-
+        send_typing_indicator(client, update.get_message().id)
         
-        from digitalguide.db_objects import WhatsAppInteraction
-        WhatsAppInteraction(user=context["user_id"],
+        if not ("user_id" in context.keys()):
+            wa_user = WhatsAppUser(ProfileName=update.entry[0].changes[0].value.contacts[0].profile_name,
+                                   WaId=update.get_from())
+            context["user_id"] = wa_user.id
+        
+        
+        wa_interaction = WhatsAppInteraction(user=context["user_id"],
                             ProfileName=update.entry[0].changes[0].value.contacts[0].profile_name,
                             WaId=update.get_from(),
                             text=update.get_message_text(),
                             state=context["state"]
-                            ).save()
+                            )
 
         for item in self.actions:
-            send_typing_indicator(client, update.get_message_id())
             if item["type"] == "return":
                 return item["state"]
             
-            max_wait_itteration = 100
+            send_typing_indicator(client, update.get_message().id)
+            
+            max_wait_itteration = 10
             for i in range(max_wait_itteration):
-                logging.info("unsend messages iterration {}: {}".format(i, r_unsend_messages.get(update.get_from())))
                 if not r_unsend_messages.get(update.get_from()):
-                    logging.info("BREAK")
+                    logging.info("Previous messages were send within {} s.".format(i))
                     break
-                sleep(.1)
+                sleep(1)
             else:
-                logging.info("Previous messages were not send within {} ms.".format(max_wait_itteration))
+                logging.info("Previous messages were not send within {} s.".format(max_wait_itteration))
 
             try:
                 result_json = None
@@ -207,4 +205,7 @@ class Action():
                     r_unsend_messages.set(update.get_from(), result_json["messages"][0]["id"], ex=10)
             except Exception as e:
                 logging.exception("Error during the Execution of action: {item}")
+        
+        wa_user.save()
+        wa_interaction.save()
     
\ No newline at end of file
