@@ -59,10 +59,13 @@ WEITER_PATTERN ="^("\
 
 DATENSCHUTZ_PATTERN = "^("\
                         "Datenschutz 🤩|"\
-                        "Datenschutz"\
+                        "Datenschutz|"\
+                        "Datenschutz 🔍"\
                         ")$"
 
-WOHIN_PATTERN = "^("\
+WOHIN_PATTERN = "("\
+    "Wohin? 🧭|"\
+    "Wohin 🧭|"\
     "wohin 🧭|"\
     "wohin 🗺️|"\
     "wohin|"\
@@ -82,9 +85,14 @@ WOHIN_PATTERN = "^("\
     "hilfe|"\
     "wie|"\
     "Wie"\
-    ")$"
+    ")"
 
 JA_PATTERN = "^("\
+    "Ja! 🤩"\
+    "Ja bitte 👍|"\
+    "Na klar 🤩|"\
+    "Juhu 🎉|"\
+    "Ja, bitte! 👍|"\
     "Die ganze Runde! 🤩|"\
     "ja 🤗|"\
     "ja 🤩|"\
@@ -222,7 +230,11 @@ JA_PATTERN = "^("\
     ")$"
 
 NEIN_PATTERN = "^("\
+    "Nein, heute nicht! 👋|"\
+    "Nein, danke! 🙂‍↔️|"\
+    "Nein, danke! 👎|"\
     "Nein, danke 👎|"\
+    "Nein, heute nicht! 👋|"\
     "nein, heute nicht 👋|"\
     "Nein danke 👎|"\
     "Die kurze Runde! 😴|"\
